==> skill-home-25.0.7-sources.jar: com/ptteng/common/skill/util/CheckDataUtil.java <==
package com.ptteng.common.skill.util;

import com.gemantic.common.util.MyListUtil;
import com.ptteng.common.skill.model.User;
import org.apache.commons.lang3.StringUtils;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by ouyang on 2016/12/16.
 */
public class CheckDataUtil {

    /**
     * 校验字符串为合法手机号码
     * 1-字符串不为空
     * 2-第一位为“1”
     * 3-纯数字
     * 4-11位字符串
     *
     * @param mobile
     * @return true-正常手机号 false-非法手机号
     */
    public static boolean checkMobile(String mobile) {

        if (StringUtils.isBlank(mobile)) {
            return false;
        }

        if ("1".equals(mobile.charAt(0))) {
            return false;
        }

        int size = mobile.length();
        for (int i = 1; i < size; i++) {
            if (CheckDataUtil.isNotDigit(mobile.charAt(i))) {
                return false;
            }
        }

        return mobile.length() == 11 ? true : false;
    }

    /***
     * 校验是否需要增加用户拓展信息
     *
     * @param oldStatus
     * @param newStatus
     * @return true-需要 false-不需要
     */
    public static boolean needAddTeacher(Integer oldStatus, Integer newStatus) {
        if (isNull(oldStatus) || isNull(newStatus)) {
            return false;
        }
        return (isStudent(oldStatus) && isTeacher(newStatus)) ? true : false;
    }


    public static boolean isNotDigit(char c) {
        return !(Character.isDigit(c));
    }

    public static boolean isNotNull(Object object) {
        return !(isNull(object));
    }

    public static boolean isNull(Object object) {
        return null == object ? true : false;
    }

    public static boolean notEqual(Long num1, Long num2) {
        if (isNull(num1) || isNull(num2)) {
            return false;
        }
        return !(num1.equals(num2));
    }

    public static boolean notEqual(Integer num1, Integer num2) {
        if (isNull(num1) || isNull(num2)) {
            return false;
        }
        return !(num1.equals(num2));
    }

    public static boolean equal(Long num1, Long num2) {
        if (isNull(num1) || isNull(num2)) {
            return false;
        }
        return num1.equals(num2);
    }

    public static boolean equal(Integer num1, Integer num2) {
        if (isNull(num1) || isNull(num2)) {
            return false;
        }
        return num1.equals(num2);
    }

    public static boolean isTeacher(Integer status) {
        if (isNull(status)) {
            return false;
        }
        return status.equals(User.Status_Teacher) ? true : false;
    }

    public static boolean isStudent(Integer status) {
        if (isNull(status)) {
            return false;
        }
        return status.equals(User.Status_Student) ? true : false;
    }

    //检验是否是知乎落地页
    public static boolean isZhihu(HttpServletRequest request) {
        if (isNull(request) || isNull(request.getHeader("Referer"))) {
            return false;
        }
        return request.getHeader("Referer").contains("zhihu") ? true : false;
    }


    /**
     * html转义,防止恶意js注入
     * StringEscapeUtils.escapeHtml() 如果是英文内容，没有任何问题，然而它将一个中文字符转换成了8个字符。
     * 在UTF-8的编码 中，每个汉字占用三个字节，每个英文字符占用一个字节。这样的转换造成了大量的空间浪费。
     * 简单的办法是自己写一个escapeHtml方法，替换左右尖括号就可以了。
     * 虽然还有一些HTML entity未被转换，可能造成输出的网页不符合web标准，
     * 但是大部分浏览器都可以正常显示也就够了
     *
     * @param source
     * @return
     */
    public static String htmlEncode(String source) {
        if (source == null) {
            return "";
        }
        String html = "";
        html = source.replaceAll("<", "&lt;").replaceAll(">", "&gt;");
        return html;
    }




}

==> skill-home-28.0.2-sources.jar: com/ptteng/common/skill/util/CheckDataUtil.java <==
package com.ptteng.common.skill.util;

import com.gemantic.common.util.MyListUtil;
import com.ptteng.common.skill.model.User;
import org.apache.commons.lang3.StringUtils;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by ouyang on 2016/12/16.
 */
public class CheckDataUtil {

    /**
     * 校验字符串为合法手机号码
     * 1-字符串不为空
     * 2-第一位为“1”
     * 3-纯数字
     * 4-11位字符串
     *
     * @param mobile
     * @return true-正常手机号 false-非法手机号
     */
    public static boolean checkMobile(String mobile) {

        if (StringUtils.isBlank(mobile)) {
            return false;
        }

        if ("1".equals(mobile.charAt(0))) {
            return false;
        }

        int size = mobile.length();
        for (int i = 1; i < size; i++) {
            if (CheckDataUtil.isNotDigit(mobile.charAt(i))) {
                return false;
            }
        }

        return mobile.length() == 11 ? true : false;
    }

    /***
     * 校验是否需要增加用户拓展信息
     *
     * @param oldStatus
     * @param newStatus
     * @return true-需要 false-不需要
     */
    public static boolean needAddTeacher(Integer oldStatus, Integer newStatus) {
        if (isNull(oldStatus) || isNull(newStatus)) {
            return false;
        }
        return (isStudent(oldStatus) && isTeacher(newStatus)) ? true : false;
    }


    public static boolean isNotDigit(char c) {
        return !(Character.isDigit(c));
    }

    public static boolean isNotNull(Object object) {
        return !(isNull(object));
    }

    public static boolean isNull(Object object) {
        return null == object ? true : false;
    }

    public static boolean notEqual(Long num1, Long num2) {
        if (isNull(num1) || isNull(num2)) {
            return false;
        }
        return !(num1.equals(num2));
    }

    public static boolean notEqual(Integer num1, Integer num2) {
        if (isNull(num1) || isNull(num2)) {
            return false;
        }
        return !(num1.equals(num2));
    }

    public static boolean equal(Long num1, Long num2) {
        if (isNull(num1) || isNull(num2)) {
            return false;
        }
        return num1.equals(num2);
    }

    public static boolean equal(Integer num1, Integer num2) {
        if (isNull(num1) || isNull(num2)) {
            return false;
        }
        return num1.equals(num2);
    }

    public static boolean isTeacher(Integer status) {
        if (isNull(status)) {
            return false;
        }
        return status.equals(User.Status_Teacher) ? true : false;
    }

    public static boolean isStudent(Integer status) {
        if (isNull(status)) {
            return false;
        }
        return status.equals(User.Status_Study_Offline) ? true : false;
    }

    //检验是否是知乎落地页
    public static boolean isZhihu(HttpServletRequest request) {
        if (isNull(request) || isNull(request.getHeader("Referer"))) {
            return false;
        }
        return request.getHeader("Referer").contains("zhihu") ? true : false;
    }


    /**
     * html转义,防止恶意js注入
     * StringEscapeUtils.escapeHtml() 如果是英文内容，没有任何问题，然而它将一个中文字符转换成了8个字符。
     * 在UTF-8的编码 中，每个汉字占用三个字节，每个英文字符占用一个字节。这样的转换造成了大量的空间浪费。
     * 简单的办法是自己写一个escapeHtml方法，替换左右尖括号就可以了。
     * 虽然还有一些HTML entity未被转换，可能造成输出的网页不符合web标准，
     * 但是大部分浏览器都可以正常显示也就够了
     *
     * @param source
     * @return
     */
    public static String htmlEncode(String source) {
        if (source == null) {
            return "";
        }
        String html = "";
        html = source.replaceAll("<", "&lt;").replaceAll(">", "&gt;");
        return html;
    }




}
